import React, { useContext, useState } from "react";
import { motion } from "framer-motion";

import { Button } from "antd";
import QuillEditor from "@web/src/components/common/editor/quill/QuillEditor";
import { PostDetailContext } from "./context/PostDetailContext";
import { usePost } from "@nice/client";
import { PostType } from "@nice/common";
import toast from "react-hot-toast";
import { isContentEmpty } from "./utils";
import { SendOutlined } from "@ant-design/icons";
import { TusUploader } from "@web/src/components/common/uploader/TusUploader";
export default function PostCommentEditor() {
	const { post } = useContext(PostDetailContext);
	const [content, setContent] = useState("");
	const [isPreview, setIsPreview] = useState(false);
	const [fileIds, setFileIds] = useState<string[]>([]);
	const { create } = usePost();
	const handleSubmit = async (e: React.FormEvent) => {
		e.preventDefault();
		if (isContentEmpty(content)) {
			toast.error("内容不得为空");
			return;
		}

		try {
			await create.mutateAsync({
				data: {
					type: PostType.POST_COMMENT,

					parentId: post?.id,
					content: content,
					resources: {
						connect: fileIds.filter(Boolean).map((id) => ({
							fileId: id,
						})),
					},
				},
			});
			toast.success("发布成功！");
			setContent("");
		} catch (error) {
			toast.error("发布失败，请稍后重试");
			console.error("Error posting comment:", error);
		}
		// TODO: 实现提交逻辑
		console.log("Submitting:", content);
		setContent("");
	};

	return (
		<motion.div
			initial={{ opacity: 0, y: 20 }}
			animate={{ opacity: 1, y: 0 }}
			className="w-full mx-auto mt-4">
			<form onSubmit={handleSubmit} className="space-y-3">
				<div className="relative rounded-lg border border-slate-200 bg-white shadow-sm">
					{!isPreview ? (
						<QuillEditor
							value={content}
							onChange={setContent}
							placeholder="写下你的回复..."
							className="bg-transparent"
							theme="snow"
							minRows={6}
							maxRows={12}
							modules={{
								toolbar: [
									["bold", "italic", "strike"],
									["blockquote", "code-block"],
									[{ list: "ordered" }, { list: "bullet" }],
									["link"],
									["clean"],
								],
							}}
							style={
								{
									"--ql-border-color": "transparent",
									"--ql-toolbar-bg": "rgb(248, 250, 252)", // slate-50
								} as React.CSSProperties
							}
						/>
					) : (
						<motion.div
							initial={{ opacity: 0 }}
							animate={{ opacity: 1 }}
							className="ql-editor p-4 min-h-[120px] text-slate-800 prose prose-slate max-w-none quill-editor-container"
							dangerouslySetInnerHTML={{ __html: content }}
						/>
					)}
				</div>

				<TusUploader
					onChange={(value) => {
						setFileIds(value);
					}}></TusUploader>

				<div className="flex items-center justify-end">
					<motion.div
						whileHover={{ scale: 1.02 }}
						whileTap={{ scale: 0.98 }}>
						<Button
							type="primary"
							htmlType="submit"
							disabled={isContentEmpty(content)}
							className="flex items-center space-x-2 bg-primary"
							icon={<SendOutlined />}>
							提交
						</Button>
					</motion.div>
				</div>
			</form>
		</motion.div>
	);
}
