import { createContext, useContext, ReactNode } from "react";
import { Form, FormInstance } from "antd";
import { api, usePost } from "@nice/client";
import toast from "react-hot-toast";
import { useNavigate } from "react-router-dom";
import { PostState, PostType } from "@nice/common";

export interface LetterFormData {
	title: string;
	content: string;
	resources?: string[];
	receivers?: string[];
	terms?: string[];
	isPublic?: boolean;
	signature?: string;
	meta: {
		tags: string[];
		signature?: string;
	};
}
interface LetterEditorContextType {
	onSubmit: (values: LetterFormData) => Promise<void>;
	receiverId?: string;
	termId?: string;
	form: FormInstance<LetterFormData>;
}

interface LetterFormProviderProps {
	children: ReactNode;
	receiverId?: string;
	termId?: string;
}

const LetterEditorContext = createContext<LetterEditorContextType | null>(null);

export function LetterFormProvider({
	children,
	receiverId,
	termId,
}: LetterFormProviderProps) {
	const { create } = usePost();
	const navigate = useNavigate();
	const [form] = Form.useForm<LetterFormData>();

	const onSubmit = async (data: LetterFormData) => {
		try {
			console.log("data", data);
			const receivers = data?.receivers;
			const terms = data?.terms;
			delete data.receivers;
			delete data.terms;
			const result = await create.mutateAsync({
				data: {
					...data,
					type: PostType.POST,
					terms: {
						connect: (terms || [])?.filter(Boolean).map((id) => ({
							id,
						})),
					},
					receivers: {
						connect: (receivers || [])
							?.filter(Boolean)
							.map((id) => ({
								id,
							})),
					},
					state: PostState.PENDING,
					isPublic: data?.isPublic,

					resources: data.resources?.length
						? {
								connect: (
									data.resources?.filter(Boolean) || []
								).map((fileId) => ({
									fileId,
								})),
							}
						: undefined,
				},
			});
			// console.log(123);
			navigate(`/${result.id}/detail`, { replace: true });
			toast.success("发送成功！");
			form.resetFields();
		} catch (error) {
			console.error("Error submitting form:", error);
			toast.error("操作失败，请重试！");
		}
	};

	return (
		<LetterEditorContext.Provider
			value={{
				onSubmit,
				receiverId,
				termId,
				form,
			}}>
			<Form<LetterFormData>
				form={form}
				initialValues={{ meta: { tags: [] } }}>
				{children}
			</Form>
		</LetterEditorContext.Provider>
	);
}

export const useLetterEditor = () => {
	const context = useContext(LetterEditorContext);
	if (!context) {
		throw new Error(
			"useLetterEditor must be used within LetterFormProvider"
		);
	}
	return context;
};
